summaryrefslogtreecommitdiffstats
path: root/src/appliance.c
diff options
context:
space:
mode:
authorRichard W.M. Jones <rjones@redhat.com>2012-03-03 16:58:05 +0000
committerRichard W.M. Jones <rjones@redhat.com>2012-03-03 16:58:05 +0000
commit49726b9269490e331e740d55952da87552ca2500 (patch)
tree7fda2a339b90c9b708fbdee1c383e63ca9c41e4d /src/appliance.c
parentba468e9c5ecb32046299dd69a6e045f2aa7ba982 (diff)
downloadlibguestfs-49726b9269490e331e740d55952da87552ca2500.tar.gz
libguestfs-49726b9269490e331e740d55952da87552ca2500.tar.xz
libguestfs-49726b9269490e331e740d55952da87552ca2500.zip
Rebrand 'ordinary appliance' as 'old-style appliance'.
This is just code motion.
Diffstat (limited to 'src/appliance.c')
-rw-r--r--src/appliance.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/appliance.c b/src/appliance.c
index 0ece4d27..50e614fc 100644
--- a/src/appliance.c
+++ b/src/appliance.c
@@ -48,7 +48,7 @@ static const char *initrd_name = "initramfs." host_cpu ".img";
static int find_path (guestfs_h *g, int (*pred) (guestfs_h *g, const char *pelem, void *data), void *data, char **pelem);
static int dir_contains_file (const char *dir, const char *file);
static int dir_contains_files (const char *dir, ...);
-static int contains_ordinary_appliance (guestfs_h *g, const char *path, void *data);
+static int contains_old_style_appliance (guestfs_h *g, const char *path, void *data);
static int contains_supermin_appliance (guestfs_h *g, const char *path, void *data);
static char *calculate_supermin_checksum (guestfs_h *g, const char *supermin_path);
static int check_for_cached_appliance (guestfs_h *g, const char *supermin_path, const char *checksum, uid_t uid, char **kernel, char **initrd, char **appliance);
@@ -61,12 +61,12 @@ static void print_febootstrap_command_line (guestfs_h *g, const char *argv[]);
*
* This function locates or builds the appliance as necessary,
* handling the supermin appliance, caching of supermin-built
* appliances, or using an ordinary appliance.
*
* The return value is 0 = good, -1 = error. Returned in '*kernel'
* will be the name of the kernel to use, '*initrd' the name of the
* initrd, '*appliance' the name of the ext2 root filesystem.
* '*appliance' can be NULL, meaning that we are using an ordinary
* (non-ext2) appliance. All three strings must be freed by the
* caller. However the referenced files themselves must not be
* deleted.
@@ -86,7 +86,7 @@ static void print_febootstrap_command_line (guestfs_h *g, const char *argv[]);
* (4) Try to build the supermin appliance. If this is successful,
* return it.
*
* (5) Check each element of g->path, looking for an ordinary appliance.
* If one is found, return it.
*
* The supermin appliance cache directory lives in
@@ -163,7 +163,7 @@ guestfs___build_appliance (guestfs_h *g,
/* Step (5). */
char *path;
- r = find_path (g, contains_ordinary_appliance, NULL, &path);
+ r = find_path (g, contains_old_style_appliance, NULL, &path);
if (r == -1)
return -1;
@@ -179,13 +179,13 @@ guestfs___build_appliance (guestfs_h *g,
return 0;
}
- error (g, _("cannot find any suitable libguestfs supermin or ordinary appliance on LIBGUESTFS_PATH (search path: %s)"),
+ error (g, _("cannot find any suitable libguestfs supermin or old-style appliance on LIBGUESTFS_PATH (search path: %s)"),
g->path);
return -1;
}
static int
-contains_ordinary_appliance (guestfs_h *g, const char *path, void *data)
+contains_old_style_appliance (guestfs_h *g, const char *path, void *data)
{
return dir_contains_files (path, kernel_name, initrd_name, NULL);
}
@@ -61,12 +61,12 @@ static void print_febootstrap_command_line (guestfs_h *g, const char *argv[]);
* This function locates or builds the appliance as necessary,
* handling the supermin appliance, caching of supermin-built
- * appliances, or using an ordinary appliance.
+ * appliances, or using an old-style appliance.
*
* The return value is 0 = good, -1 = error. Returned in '*kernel'
@@ -61,12 +61,12 @@ static void print_febootstrap_command_line (guestfs_h *g, const char *argv[]);
* will be the name of the kernel to use, '*initrd' the name of the
* initrd, '*appliance' the name of the ext2 root filesystem.
- * '*appliance' can be NULL, meaning that we are using an ordinary
+ * '*appliance' can be NULL, meaning that we are using an old-style
* (non-ext2) appliance. All three strings must be freed by the
* caller. However the referenced files themselves must not be
@@ -86,7 +86,7 @@ static void print_febootstrap_command_line (guestfs_h *g, const char *argv[]);
* return it.
*
- * (5) Check each element of g->path, looking for an ordinary appliance.
+ * (5) Check each element of g->path, looking for an old-style appliance.
* If one is found, return it.
*